@@ -1,5 +1,5 @@
+from aidial_sdk._pydantic import Field, StrictStr
 from aidial_sdk.deployment.from_request_mixin import FromRequestDeploymentMixin
-from aidial_sdk.pydantic_v1 import Field, StrictStr
 
 
 class RateRequest(FromRequestDeploymentMixin):
